@@ -1229,7 +1229,7 @@ plugin_solidigm_opts () {
 		opts+=" --raw-binary -b"
 			;;
 		"workload-tracker")
-		opts+=" --enable -e --disable -d --sample-time= -s \
+		opts+=" --uuid-index= -U --enable -e --disable -d --sample-time= -s \
 		--type= -t --run-time= -r --flush-freq= -f \
 		--wall-clock -w --trigger-field= -T \
 		--trigger-threshold= -V --trigger-on-delta -D \
@@ -1531,6 +1531,38 @@ plugin_inspur_opts () {
 	return 0
 }
 
+plugin_mangoboost_opts () {
+	local opts=""
+	local compargs=""
+
+	local nonopt_args=0
+	for (( i=0; i < ${#words[@]}-1; i++ )); do
+		if [[ ${words[i]} != -* ]]; then
+			let nonopt_args+=1
+		fi
+	done
+
+	if [ $nonopt_args -eq 3 ]; then
+		opts="/dev/nvme* "
+	fi
+
+	opts+=" "
+
+	case "$1" in
+		"id-ctrl")
+		opts+=" --raw-binary -b --human-readable -H \
+			--vendor-specific -v --output-format= -o"
+			;;
+		"help")
+		opts+=$NO_OPTS
+			;;
+	esac
+
+	COMPREPLY+=( $( compgen $compargs -W "$opts" -- $cur ) )
+
+	return 0
+}
+
 plugin_ocp_opts () {
 	local opts=""
 	local compargs=""
@@ -1616,6 +1648,18 @@ plugin_ocp_opts () {
 		opts+=" --comp-id= -i --list -l --verbose -v \
 			--output-format -o --timeout= -t"
 			;;
+		"get-latency-monitor")
+		opts+=" --sel= -s \
+			--namespace-id= -n --no-uuid -u"
+			;;
+		"get-clear-pcie-correctable-errors")
+		opts+=" --sel= -s \
+			--namespace-id= -n --no-uuid -u"
+			;;
+		"get-telemetry-profile")
+		opts+=" --sel= -s \
+			--namespace-id= -n --no-uuid -u"
+			;;
 		"help")
 		opts+=$NO_OPTS
 			;;
@@ -1697,7 +1741,9 @@ _nvme_subcmds () {
 			telemetry-string-log set-telemetry-profile \
 			set-dssd-async-event-config get-dssd-async-event-config \
 			get-error-injection set-error-injection \
-			hardware-component-log"
+			hardware-component-log get-latency-monitor \
+			get-clear-pcie-correctable-errors get-telemetry-profile"
+		[mangoboost]="id-ctrl"
 	)
 
 	# Associative array mapping plugins to corresponding option completions
@@ -1723,6 +1769,7 @@ _nvme_subcmds () {
 		[ymtc]="plugin_ymtc_opts"
 		[inspur]="plugin_inspur_opts"
 		[ocp]="plugin_ocp_opts"
+		[mangoboost]="plugin_mangoboost_opts"
 	)
 
 	# Top level commands
