@@ -15,6 +15,7 @@
 #include "util/suffix.h"
 #include "util/types.h"
 #include "common.h"
+#include "logging.h"
 
 #define nvme_print(name, flags, ...)				\
 	do {							\
@@ -262,7 +263,7 @@ void nvme_show_persistent_event_log(void *pevent_log_info,
 }
 
 void nvme_show_endurance_group_event_agg_log(
-	struct nvme_aggregate_predictable_lat_event *endurance_log,
+	struct nvme_aggregate_endurance_group_event *endurance_log,
 	__u64 log_entries, __u32 size, const char *devname,
 	nvme_print_flags_t flags)
 {
@@ -490,9 +491,9 @@ void nvme_show_single_property(int offset, uint64_t value64, nvme_print_flags_t
 	nvme_print(single_property, flags, offset, value64);
 }
 
-void nvme_show_relatives(const char *name)
+void nvme_show_relatives(nvme_root_t r, const char *name, nvme_print_flags_t flags)
 {
-	/* XXX: TBD */
+	nvme_print(relatives, flags, r, name);
 }
 
 void d(unsigned char *buf, int len, int width, int group)
@@ -1667,3 +1668,8 @@ void nvme_show_pull_model_ddc_req_log(struct nvme_pull_model_ddc_req_log *log,
 {
 	nvme_print(pull_model_ddc_req_log, flags, log);
 }
+
+void nvme_show_log(const char *devname, struct nvme_get_log_args *args, nvme_print_flags_t flags)
+{
+	nvme_print(log, flags, devname, args);
+}
