@@ -32,7 +32,7 @@ struct print_ops {
 	void (*directive)(__u8 type, __u8 oper, __u16 spec, __u32 nsid, __u32 result, void *buf, __u32 len);
 	void (*discovery_log)(struct nvmf_discovery_log *log, int numrec);
 	void (*effects_log_list)(struct list_head *list);
-	void (*endurance_group_event_agg_log)(struct nvme_aggregate_predictable_lat_event *endurance_log, __u64 log_entries, __u32 size, const char *devname);
+	void (*endurance_group_event_agg_log)(struct nvme_aggregate_endurance_group_event *endurance_log, __u64 log_entries, __u32 size, const char *devname);
 	void (*endurance_group_list)(struct nvme_id_endurance_group_list *endgrp_list);
 	void (*endurance_log)(struct nvme_endurance_group_log *endurance_group, __u16 group_id, const char *devname);
 	void (*error_log)(struct nvme_error_log_page *err_log, int entries, const char *devname);
@@ -64,6 +64,7 @@ struct print_ops {
 	void (*predictable_latency_event_agg_log)(struct nvme_aggregate_predictable_lat_event *pea_log, __u64 log_entries, __u32 size, const char *devname);
 	void (*predictable_latency_per_nvmset)(struct nvme_nvmset_predictable_lat_log *plpns_log, __u16 nvmset_id, const char *devname);
 	void (*primary_ctrl_cap)(const struct nvme_primary_ctrl_cap *caps);
+	void (*relatives)(nvme_root_t r, const char *name);
 	void (*resv_notification_log)(struct nvme_resv_notification_log *resv, const char *devname);
 	void (*resv_report)(struct nvme_resv_status *status, int bytes, bool eds);
 	void (*sanitize_log_page)(struct nvme_sanitize_log_page *sanitize_log, const char *devname);
@@ -97,6 +98,7 @@ struct print_ops {
 	void (*host_discovery_log)(struct nvme_host_discover_log *log);
 	void (*ave_discovery_log)(struct nvme_ave_discover_log *log);
 	void (*pull_model_ddc_req_log)(struct nvme_pull_model_ddc_req_log *log);
+	void (*log)(const char *devname, struct nvme_get_log_args *args);
 
 	/* libnvme tree print functions */
 	void (*list_item)(nvme_ns_t n);
@@ -153,7 +155,7 @@ struct print_ops *nvme_get_binary_print_ops(nvme_print_flags_t flags);
 
 void nvme_show_status(int status);
 void nvme_show_lba_status_info(__u32 result);
-void nvme_show_relatives(const char *name);
+void nvme_show_relatives(nvme_root_t r, const char *name, nvme_print_flags_t flags);
 
 void nvme_show_id_iocs(struct nvme_id_iocs *iocs, nvme_print_flags_t flags);
 void nvme_show_id_ctrl(struct nvme_id_ctrl *ctrl, nvme_print_flags_t flags,
@@ -199,7 +201,7 @@ void nvme_show_persistent_event_log(void *pevent_log_info,
 	__u8 action, __u32 size, const char *devname,
 	nvme_print_flags_t flags);
 void nvme_show_endurance_group_event_agg_log(
-	struct nvme_aggregate_predictable_lat_event *endurance_log,
+	struct nvme_aggregate_endurance_group_event *endurance_log,
 	__u64 log_entries, __u32 size, const char *devname,
 	nvme_print_flags_t flags);
 void nvme_show_lba_status_log(void *lba_status, __u32 size,
@@ -358,6 +360,7 @@ void nvme_show_host_discovery_log(struct nvme_host_discover_log *log, nvme_print
 void nvme_show_ave_discovery_log(struct nvme_ave_discover_log *log, nvme_print_flags_t flags);
 void nvme_show_pull_model_ddc_req_log(struct nvme_pull_model_ddc_req_log *log,
 				      nvme_print_flags_t flags);
+void nvme_show_log(const char *devname, struct nvme_get_log_args *args, nvme_print_flags_t flags);
 
 extern char *alloc_error;
 #endif /* NVME_PRINT_H */
